    ingredient scan:

    	databases:
    		essentials

    		cautionary

    	status:
    		python3 insurance.py "shows/ingredient_scan/**/status_*.py"

    	important:
    		#
    		#	This builds the proceeds of the scan
    		#
    		land.build
    			grove.nurture

    	(with exceptions) breakdown:
    		This might need to include "cautionary nutrients" also.

    			Therefore, "FDA ingredients chart"

    			Therefore, "essential (and cautionary) nutrients"
    			Therefore, "essential (to include) nutrients"
    			Therefore, "relevant nutrients"

    	description:
    		https://fdc.nal.usda.gov/portal-data/external/fullNutrientList

    		This is for an "Essential Nutrients" panel.

    		This is based on the essential nutrients defined by the FDA:
    			https://www.fda.gov/food/nutrition-facts-label/daily-value-nutrition-and-supplement-facts-labels

    	relevant:
    		import apoplast.layouts.ingredient_scan